App.LicenseController = Ember.ObjectController.extend({
    save: function() {
        m = this.get("model");

        controller = this;
        $.ajax({
            url: "https://secure.expandrive.com/store/order/license",
            type: "POST",
            data: {
                serial: m.get("serial")
            },
            success: function(data) {
                alert("Thanks for purchasing Strongsync!");
                controller.transitionToRoute('index');
                file.writeLicense(data);
                strongsync.stopAll();
                setTimeout(function() {
                    strongsync.startAll();
                }, 1000);
            },
            error: function(XMLHttpRequest, textStatus, errorThrown) {
                alert("Invalid serial number");
            }
        });
    },

});


App.LicenseView = Ember.View.extend({
    didInsertElement: function() {
        $("#serialInput").focus();
    }
});



App.LicenseRoute = Ember.Route.extend({
    model: function() {
        return App.license;
    }
});

App.License = Ember.Model.extend({

    serial: null,

    license: {},

    _licenseString: "",

    licenseString: function(key, value) {
        if(arguments.length > 1) {
            this.set("_licenseString", value);
            json = plist_to_json(value);
            json["Signature"] = json["Signature"].replace(/\ /g, "");
            this.set("license", json);
            license.setLicenseString(value);
        }

        return this.get("_licenseString");
    }.property(),

    activateSerial: function(callback, context) {
        self = this;
        $.ajax({
          url: "https://secure.expandrive.com/store/order/license",
          type: "POST",
          data: {
            "serial": this.get("serial"),
            "email": this.get("email"),
            "previous_sha1": license.licenseSHA1()
          },
          success: function(data) {
            App.license.set("licenseString", data);
            callback.call(context);
          },
          error: function(data) {
            alert("Could not activate this license. Please make sure you're connect to the internet and that you've typed the license in correctly.");
          }
        });
    },

    requestTrial: function(name, email, callback, context) {
        self = this;
        $.ajax({
          url: "https://secure.expandrive.com/store/order/request_trial",
          type: "POST",
          data: {
            "name": name,
            "email": email,
            "previous_sha1": license.licenseSHA1()
          },
          success: function(data) {
            App.license.set("licenseString", data);
            callback.call(context);
          },
          error: function(data) {
            alert("Could not activate free trial. Please make sure you're connect to the internet.");
          }
        });
    },

    validate: function() {
        if (this.inTrial() && this.daysLeftInTrial() < 0) {
            alert("Your free trial has expired and ExpanDrive will close after 10 minutes.");
            return setTimeout((function() {
                if (this.inTrial) {
                    settings.sendToStore();
                    return expandrive.quit();
                }
            }), 60 * 10 * 1000);
        }
    }.property("license"),

    getString: function(key) {
        return license.getString(key);
    },

    licenseSHA1: function() {
        return license.getSHA1();
    }.property("license"),

    validForVersion: function() {
        if (this.getString("product_version") !== "") {
            return this.getString("product_version");
        }
        if (this.getString("version") !== "") {
            return this.getString("version");
        }
        return "1";
    },

    statusMessage: function() {
        if (this.inTrial()) {
            return this.validV3TrialLicenseMessage();
        }
        if (!this.needsLicense) {
            return this.validV3LicenseMessage();
        }
        if (this.validForVersion() === "2") {
            return this.validV2LicenseMessage();
        }
        return "" + (this.validForVersion()) + " " + (this.inTrial());
    }.property("license"),

    daysLeftInTrial: function() {
        var d, days_left, today;
        if (this.getString("in_trial") === "true") {
            today = new Date();
            d = Date.parse(this.getString('valid_until'));
            days_left = Math.floor(((d - today) / (60 * 60 * 24 * 1000)) + 1);
            return days_left;
        } else {
            return 0;
        }
    },

    validV3TrialLicenseMessage: function() {
        var days_left;
        days_left = this.daysLeftInTrial();
        if (days_left > 1) {
            return "" + days_left + " days left in your free trial.";
        } else if (days_left === 1 || days_left === 0) {
            return "1 day left in your free trial.";
        } else {
            return "Your free trial has expired";
        }
    },

    validV3LicenseMessage: function() {
        return "Registered to " + (this.getString('name'));
    },

    validV2LicenseMessage: function() {
        return "You are currently licensed for an older version of ExpanDrive.";
    },

    upgradeButtonPrompt: function() {
        if (this.validForVersion() === "2" || this.validForVersion() === "1") {
            return "Upgrade to ExpanDrive 3";
        } else {
            return "Buy an ExpanDrive 3 license";
        }
    }.property("license"),

    inTrial: function() {
        if (this.getString("in_trial") === "true" && this.validForVersion() === "3") {
            return true;
        } else {
            return false;
        }
    },

    needsLicense: function() {
        if (this.validForVersion() === "3" && !this.inTrial()) {
            return false;
        } else {
            return true;
        }
    }.property("license"),

    newUser: function() {
        if (license.validLicense() === false || this.validForVersion() !== "3") {
            return true;
        }
        return false;
    }.property("license"),

    activeLicense: function() {
        if (this.get("newUser")) {
            return false;
        }
        return true;
    }.property("license"),

    attemptV3AutoUpgrade: function() {
        return $.ajax({
            url: "https://secure.expandrive.com/store/order/license",
            type: "POST",
            data: {
                "previous_sha1": license.licenseV2SHA1()
            },
            success: function(data) {
                alert("You have been automatically upgraded to ExpanDrive 3!");
                license.setLicenseString(data);
                Strongspace.Sidebar.render();
                Strongspace.Details.render();
                Strongspace.Settings.render();
                return Strongspace.newSession();
            }
        });
    },

});

App.license = App.License.create();
